@@ -1,11 +1,13 @@
 package App::skryf::Command::setup;
 
-our $VERSION = '0.016_02'; # VERSION
+our $VERSION = '0.016_03'; # VERSION
 
 use Mojo::Base 'Mojolicious::Command';
+use Mojo::Util qw(hmac_sha1_sum);
 use FindBin '$Bin';
 use Carp;
 use IO::Prompt;
+use App::skryf::Model::User;
 
 has description => "Setup Skryf.\n";
 has usage       => <<"EOF";
@@ -16,9 +18,9 @@ EOF
 
 sub run {
     my ($self, @args) = @_;
-    my $model = $self->app->db('User');
+    my $model = App::skryf::Model::User->new;
 
-    say "CMS Setup";
+    say "Skryf Setup";
     my $username = prompt('Username: ', -tty);
     my $password = prompt('Password: ', -echo => '*', -tty);
     if ($model->get({username => $username})) {
@@ -26,7 +28,7 @@ sub run {
           "The user: $username already exists in the database.\n",
           "Please remove if you wish to re-auth";
     }
-    $model->create($username, $self->app->bcrypt($password));
+    $model->create($username, hmac_sha1_sum($self->app->secrets->[0], $password));
     say "Skryf Setup completed.";
 }
 1;
