@@ -1,10 +1,11 @@
 package App::skryf::Model::Base;
 
-our $VERSION = '0.016_02'; # VERSION
+our $VERSION = '0.016_03'; # VERSION
 
 use Mojo::Base -base;
 use Mango;
 use Method::Signatures;
+use DDP;
 
 has mpath => 'mongodb://localhost:27017/';
 has dbname => $ENV{TEST_ONLINE} || 'skryf';
@@ -13,6 +14,10 @@ method mgo {
     Mango->new($self->mpath.$self->dbname);
 }
 
+method current_db {
+    return $self->dbname;
+}
+
 1;
 __END__
 
