@@ -1,6 +1,6 @@
 package App::skryf::Model::User;
 
-our $VERSION = '0.016_02'; # VERSION
+our $VERSION = '0.016_03'; # VERSION
 
 use Mojo::Base 'App::skryf::Model::Base';
 use Method::Signatures;
@@ -10,6 +10,10 @@ method users {
     $self->mgo->db->collection('users');
 }
 
+method all {
+    $self->users->find()->all;
+}
+
 method create ($username, $password, $attrs = {}) {
     my $user = $self->users->find_one({username => $username});
     my $bson = bson_doc
@@ -53,6 +57,10 @@ User model
 
 Grabs user collection from Mongo
 
+=head2 B<all>
+
+Returns all users
+
 =head2 B<check>
 
 Checks username/password against database
